@@ -74,7 +74,6 @@ def find_optimset(options):
 
     outfile.close()
 
-#def find_optimset_months(diagnostic_headers_file, diagnostic_paths_file, gzip_flag):
 def find_optimset_months(options):
     import json
     import valid_experiments_months
@@ -95,7 +94,7 @@ def find_optimset_months(options):
     #Find the list of center / model with all the months for all the years / experiments and variables requested:
     diag_tree_desc_months=[
                             'experiment','center','model','rip','frequency','realm','mip',
-                            'var','version','year','month','file_type','search'
+                            'var','year','month','file_type','version','search'
                          ]
     paths_dict=valid_experiments_months.intersection(paths_dict,diag_tree_desc_path,diag_tree_desc_months)
 
@@ -113,7 +112,6 @@ def search_esgf(search_path,file_type_list,variable_list,experiment_list,diag_tr
     import esgf_query
     return esgf_query.descend_tree(search_path,file_type_list,variable_list,experiment_list,diag_tree_desc)
 
-
 def retrieval(retrieval_desc):
     import json
     #Reads the file created by find_optimset and gives the path to file:
@@ -124,7 +122,11 @@ def retrieval(retrieval_desc):
         infile=open(retrieval_desc.in_diagnostic_pointers_file,'r')
     paths_dict=json.load(infile)
 
-    tree_retrieval(retrieval_desc,paths_dict['diagnostic'],paths_dict['data_pointers'])
+    path_name=tree_retrieval(retrieval_desc,paths_dict['diagnostic'],paths_dict['data_pointers'])
+    if retrieval_desc.file_type_flag:
+        print path_name
+    else:
+        print path_name
     return
 
 def tree_retrieval(retrieval_desc,diag_desc,paths_dict):
@@ -134,7 +136,7 @@ def tree_retrieval(retrieval_desc,diag_desc,paths_dict):
         level_name=paths_dict['_name']
         if level_name in dir(retrieval_desc):
             #If the level name was specified in the retrieval, use this specification:
-            tree_retrieval(retrieval_desc,diag_desc,paths_dict[str(getattr(retrieval_desc,level_name))])
+            path_name=tree_retrieval(retrieval_desc,diag_desc,paths_dict[str(getattr(retrieval_desc,level_name))])
         elif level_name=='version':
             #the 'version' field is peculiar. Here, we use the most recent, or largest version number:
             version_list=[]
@@ -142,7 +144,7 @@ def tree_retrieval(retrieval_desc,diag_desc,paths_dict):
                 if version[0]!='_':
                     version_list.append(int(version[1:]))
             version='v'+str(max(version_list))
-            tree_retrieval(retrieval_desc,diag_desc,paths_dict[version])
+            path_name=tree_retrieval(retrieval_desc,diag_desc,paths_dict[version])
         else:
             #The level was not specified but an ordered list was provided in the diagnostic header.
             #Go through the list and pick the first avilable one:
@@ -151,13 +153,12 @@ def tree_retrieval(retrieval_desc,diag_desc,paths_dict):
                 if level in paths_dict.keys():
                     if level_name=='file_type' and retrieval_desc.file_type_flag:
                         #if the file_type_flag was used, the script outputs only the file_type
-                        print level
-                        return
-                    tree_retrieval(retrieval_desc,diag_desc,paths_dict[level])
+                        return level
+                    path_name=tree_retrieval(retrieval_desc,diag_desc,paths_dict[level])
                     break
     else:
-        print paths_dict[0]
-    return
+        path_name=paths_dict[0]
+    return path_name
 
 def simulations(simulations_desc):
     import json
